package cn.iocoder.yudao.module.sale.listener;


import cn.hutool.core.collection.CollectionUtil;
import cn.iocoder.yudao.framework.apollo.core.event.OrderAssociationOfferCostEvent;
import cn.iocoder.yudao.module.product.dto.FeeDto;
import cn.iocoder.yudao.module.product.enums.FeeTypeEnum;
import cn.iocoder.yudao.module.sale.service.offer.OfferService;
import cn.iocoder.yudao.module.sale.vo.offer.EstCostVO;
import lombok.AllArgsConstructor;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Objects;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;

/**
 * 根据订单id查询报价单信息
 *
 * @author zhengYi
 */
@Component("OrderAssociationOfferListener")
@AllArgsConstructor
public class OrderAssociationOfferListener {

    private final OfferService offerService;

    /**
     * 根据订单id查询关联报价单的费用数据
     *
     * @param event 参数与返回值
     */
    @EventListener(OrderAssociationOfferCostEvent.class)
    public void selectOfferCostByOrderId(OrderAssociationOfferCostEvent event) {
        EstCostVO estCostVO = offerService.getOfferCostByOrderId(event.getOrderId());
        if (Objects.nonNull(estCostVO)) {
            List<FeeDto> feeDtoList = estCostVO.getFeeDtoList();
            if (CollectionUtil.isNotEmpty(feeDtoList)) {
                FeeDto freightDto = feeDtoList.stream().filter(dto -> Objects.equals(FeeTypeEnum.FREIGHT.getType(), dto.getFeeType())).findFirst().orElse(null);
                if (Objects.nonNull(freightDto)){
                    event.setFreight(freightDto.getAmount());
                    event.setFreightCurrencyId(freightDto.getCurrencyId());
                    event.setAssociationOffer(true);
                }
                FeeDto clearanceDto = feeDtoList.stream().filter(dto -> Objects.equals(FeeTypeEnum.CLEARANCE_FEE.getType(), dto.getFeeType())).findFirst().orElse(null);
                if (Objects.nonNull(clearanceDto)){
                    event.setClearance(clearanceDto.getAmount());
                    event.setClearanceCurrencyId(clearanceDto.getCurrencyId());
                    event.setAssociationOffer(true);
                }
            }
        }
    }
}
